"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_dom_1 = require("react-dom");
var crossvent = require("crossvent");
var env_1 = require("../env");
var util_1 = require("../util");
var configurations_definitions_interface_1 = require("../configurations-definitions.interface");
var universal_bootstrap_app_factory_1 = require("./universal-bootstrap-app.factory");
// Google analytics
function gtag() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    var dL = Reflect.get(window, 'dataLayer') || [];
    Reflect.set(window, 'dataLayer', dL);
    dL.push(arguments);
}
// Boot element managing
function addBootElement(rootId) {
    var rootEl = util_1.createElement();
    rootEl.setAttribute('id', rootId);
    util_1.addClassNameToElement(rootEl, 'rac-root', 'rac-flex');
}
// Global error handler
function defineErrorHandler() {
    window.onerror = function (e) {
        var errorElId = '$$error-message-el';
        var errorMessageEl = document.getElementById(errorElId);
        if (!errorMessageEl) {
            errorMessageEl = util_1.createElement();
            errorMessageEl.id = '$$error-message-el';
            util_1.addClassNameToElement(errorMessageEl, 'rac-absolute-center-position');
            util_1.addClassNameToElement(errorMessageEl, 'rac-global-error-message');
        }
        errorMessageEl.innerHTML = util_1.buildErrorMessage(e, '<br>');
    };
}
function bootstrap(applicationContainer, props, bootstrapConfiguration) {
    if (bootstrapConfiguration === void 0) { bootstrapConfiguration = configurations_definitions_interface_1.DEFAULT_BOOTSTRAP_CONFIGURATION; }
    var ready = function () {
        if (bootstrapConfiguration.needToPrepareBody) {
            util_1.addClassNameToBody('rac', util_1.orNull(env_1.ENV.macPlatform, 'rac-mac'), util_1.orNull(env_1.ENV.iosPlatform, 'rac-ios'), util_1.orNull(env_1.ENV.androidPlatform, 'rac-android'), util_1.orNull(env_1.ENV.safariPlatform, 'rac-safari'));
            addBootElement(bootstrapConfiguration.rootId);
        }
        util_1.addClassNameToBody(env_1.ENV.appProfile);
        var componentClass = universal_bootstrap_app_factory_1.makeBootstrapApp(applicationContainer, props);
        react_dom_1.render(new componentClass({}).render(), document.getElementById(bootstrapConfiguration.rootId));
    };
    if (env_1.ENV.prodMode && env_1.ENV.googleKey) {
        gtag('js', new Date());
        gtag('config', env_1.ENV.googleKey);
    }
    switch (document.readyState) {
        case 'loading':
        case 'interactive':
            // We cannot use DOMContentLoaded because fonts loading and UI blinking
            crossvent.add(window, 'load', ready);
            break;
        case 'complete':
            ready();
            break;
    }
    if (bootstrapConfiguration.needToDefineErrorHandler) {
        defineErrorHandler();
    }
}
exports.bootstrap = bootstrap;
//# sourceMappingURL=bootstrap.js.map