"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var definitions_interface_1 = require("../../../definitions.interface");
var util_1 = require("../../../util");
var datefield_1 = require("../datefield");
var layout_1 = require("../../layout");
var button_1 = require("../../button");
var date_navigator_interface_1 = require("./date-navigator.interface");
var DateNavigator = /** @class */ (function (_super) {
    __extends(DateNavigator, _super);
    /**
     * @stable [29.10.2018]
     * @param {IDateNavigatorProps} props
     */
    function DateNavigator(props) {
        var _this = _super.call(this, props) || this;
        _this.onLeft = _this.onLeft.bind(_this);
        _this.onRight = _this.onRight.bind(_this);
        _this.getDisplayValue = _this.getDisplayValue.bind(_this);
        _this.isDatePickerDayOfMonthDisabled = _this.isDatePickerDayOfMonthDisabled.bind(_this);
        _this.state = { currentTime: _this.settings.dateTime.currentDate };
        if (props.time) {
            _this.delayedTask = new util_1.DelayedTask(_this.doDelay.bind(_this), 1000 * 10, true);
        }
        return _this;
    }
    /**
     * @stable [30.10.2018]
     */
    DateNavigator.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        if (util_1.isFn(this.delayedTask)) {
            this.delayedTask.start();
        }
    };
    /**
     * @stable [30.10.2018]
     */
    DateNavigator.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        if (util_1.isFn(this.delayedTask)) {
            this.delayedTask.stop();
        }
    };
    /**
     * @stable [08.01.2019]
     * @returns {JSX.Element}
     */
    DateNavigator.prototype.render = function () {
        var _this = this;
        var props = this.props;
        return (React.createElement(layout_1.FlexLayout, { row: true, full: props.full, alignItemsCenter: true },
            React.createElement(button_1.Button, { icon: 'arrow_left', mini: true, onClick: this.onLeft }),
            React.createElement(datefield_1.DateField, __assign({}, util_1.defValuesFilter(__assign({}, this.props, { type: definitions_interface_1.UNDEF, step: definitions_interface_1.UNDEF, pattern: definitions_interface_1.UNDEF, time: definitions_interface_1.UNDEF })), { shouldDisableDate: this.isDatePickerDayOfMonthDisabled, className: util_1.toClassName('rac-date-navigator', props.className), format: this.getFieldFormat(), displayValue: this.getDisplayValue })),
            React.createElement(button_1.Button, { icon: 'arrow_right', mini: true, onClick: this.onRight }),
            util_1.orNull(props.time, function () { return (React.createElement(layout_1.FlexLayout, { row: true, alignItemsCenter: true, className: 'rac-date-navigator-clock' },
                _this.uiFactory.makeIcon('clock'),
                _this.dc.fromDateTimeToPstTime(_this.state.currentTime))); })));
    };
    /**
     * @stable [07.01.2019]
     */
    DateNavigator.prototype.onLeft = function () {
        this.doManualChangeDate(-this.props.step);
    };
    /**
     * @stable [07.01.2019]
     */
    DateNavigator.prototype.onRight = function () {
        this.doManualChangeDate(this.props.step);
    };
    /**
     * @stable [07.01.2019]
     * @param {number} durationToAdd
     */
    DateNavigator.prototype.doManualChangeDate = function (durationToAdd) {
        var nextValue;
        switch (this.props.type) {
            case date_navigator_interface_1.DateNavigatorTypeEnum.DAY:
                nextValue = this.dc.tryAddXDays(durationToAdd, this.value, this.getFieldFormat());
                break;
            case date_navigator_interface_1.DateNavigatorTypeEnum.MONTH:
                nextValue = this.dc.tryAddXMonths(durationToAdd, this.value, this.getFieldFormat());
                break;
        }
        this.onChangeManually(nextValue);
    };
    /**
     * @stable [30.10.2018]
     */
    DateNavigator.prototype.doDelay = function () {
        this.setState({ currentTime: this.settings.dateTime.currentDate });
    };
    /**
     * @stable [07.01.2019]
     * @returns {string}
     */
    DateNavigator.prototype.getDisplayValue = function () {
        var props = this.props;
        var pattern = props.pattern;
        switch (props.type) {
            case date_navigator_interface_1.DateNavigatorTypeEnum.MONTH:
                pattern = 'MMMM YYYY';
                break;
        }
        var formattedDisplayValue = this.dc.format(this.value, this.getFieldFormat(), pattern);
        return util_1.isFn(props.displayValue)
            ? util_1.calc(props.displayValue, util_1.toType({
                displayValue: formattedDisplayValue, value: this.value, type: props.type, pattern: pattern,
            }))
            : formattedDisplayValue;
    };
    /**
     * @stable [08.01.2019]
     * @param {Date} currentDayOfMonth
     * @returns {boolean}
     */
    DateNavigator.prototype.isDatePickerDayOfMonthDisabled = function (currentDayOfMonth) {
        switch (this.props.type) {
            case date_navigator_interface_1.DateNavigatorTypeEnum.MONTH:
                return !this.dc.compare(this.dc.tryGetFirstDayOfMonth(0, currentDayOfMonth), currentDayOfMonth);
        }
        return false;
    };
    DateNavigator.defaultProps = {
        step: 1,
        pattern: 'D MMMM',
        type: date_navigator_interface_1.DateNavigatorTypeEnum.DAY,
        time: false,
        preventFocus: true,
        full: false,
        errorMessageRendered: false,
        clearActionRendered: false,
        label: null,
    };
    return DateNavigator;
}(datefield_1.DateField));
exports.DateNavigator = DateNavigator;
//# sourceMappingURL=date-navigator.component.js.map