"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../../util");
var definitions_interface_1 = require("../../../definitions.interface");
var universal_field_component_1 = require("./universal-field.component");
var Field = /** @class */ (function (_super) {
    __extends(Field, _super);
    function Field() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @stable [26.05.2019]
     * @returns {JSX.Element}
     */
    Field.prototype.render = function () {
        return (React.createElement("div", { className: this.getFieldClassName() },
            this.props.children,
            this.getSelfElement(),
            this.getMessageElement(),
            this.getErrorMessageElement(),
            this.getAttachmentElement(),
            this.getKeyboardElement()));
    };
    /**
     * @stable [07.01.2019]
     * @param {AnyT} currentRawValue
     */
    Field.prototype.onChangeManually = function (currentRawValue) {
        this.updateInputBeforeHTML5Validation(currentRawValue);
        _super.prototype.onChangeManually.call(this, currentRawValue);
    };
    /**
     * @stable [18.06.2018]
     * @param {IChangeEvent} event
     * @returns {AnyT}
     */
    Field.prototype.getRawValueFromEvent = function (event) {
        return event.target.value;
    };
    /**
     * @stable [17.06.2018]
     */
    Field.prototype.resetError = function () {
        if (!R.isNil(this.input.required)) {
            // Because of Flux-architecture (chicken-and-egg dilemma)
            // This flag is being set by a redux engine on a new cycle
            // Need to reset: required, pattern, etc...
            this.input.required = false;
        }
        _super.prototype.resetError.call(this);
    };
    /**
     * @stable [03.09.2018]
     * @param {IKeyboardEvent} event
     */
    Field.prototype.onKeyDown = function (event) {
        var key = event.key;
        switch (key) {
            case 'Tab':
                this.onKeyTab(event);
                break;
            case 'Enter':
                this.onKeyEnter(event);
                break;
            case 'Escape':
                this.onKeyEscape(event);
                break;
            case 'ArrowDown':
                this.onKeyArrowDown(event);
                break;
            case 'ArrowUp':
                this.onKeyArrowUp(event);
                break;
            case 'Backspace':
                this.onKeyBackspace(event);
                break;
        }
        _super.prototype.onKeyDown.call(this, event);
    };
    /**
     * @stable [20.08.2018]
     */
    Field.prototype.setFocus = function () {
        var input = this.input;
        var props = this.props;
        if (!props.preventFocus && !R.isNil(input)) {
            input.focus();
        }
    };
    Object.defineProperty(Field.prototype, "input", {
        /**
         * @stable [05.10.2018]
         * @returns {HTMLInputElement | HTMLTextAreaElement}
         */
        get: function () {
            var input = this.refs.input;
            return util_1.orNull(this.hasInput, function () { return input.inputElement || input; });
        },
        enumerable: true,
        configurable: true
    });
    Field.prototype.getSelfElement = function () {
        var _this = this;
        var props = this.props;
        return util_1.orNull(props.fieldRendered !== false, function () { return (React.createElement("div", { ref: 'self', style: props.style, className: _this.getSelfElementClassName() },
            _this.getPrefixLabelElement(),
            React.createElement("div", { className: _this.getInputElementWrapperClassName() },
                _this.getInputElement(),
                _this.getLabelElement(),
                _this.getMirrorInputElement(),
                _this.getInputCaretElement(),
                _this.getInputAttachmentElement()),
            _this.actionsElement,
            _this.getProgressLabelElement())); });
    };
    Field.prototype.getProgressLabelElement = function () {
        return null;
    };
    Object.defineProperty(Field.prototype, "actionsElement", {
        get: function () {
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Field.prototype.getLabelElement = function () {
        var _this = this;
        var props = this.props;
        return util_1.ifNotNilThanValue(props.label, function () { return (React.createElement("label", { className: 'rac-field-label' }, _this.t(props.label))); });
    };
    Field.prototype.getMirrorInputElement = function () {
        return null;
    };
    Field.prototype.getInputCaretElement = function () {
        return null;
    };
    Field.prototype.getPrefixLabelElement = function () {
        return null;
    };
    Field.prototype.getAttachmentElement = function () {
        return null;
    };
    Object.defineProperty(Field.prototype, "hasInput", {
        /**
         * @stable [05.10.2018]
         * @returns {boolean}
         */
        get: function () {
            return !R.isNil(this.refs.input);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [20.08.2018]
     */
    Field.prototype.removeFocus = function () {
        var input = this.input;
        if (!R.isNil(input)) {
            input.blur();
        }
    };
    /**
     * @stable [30.10.2018]
     * @param {IFocusEvent} event
     */
    Field.prototype.onBlur = function (event) {
        _super.prototype.onBlur.call(this, event);
        this.setState({ focused: false });
    };
    /**
     * @stable [30.10.2018]
     * @param {IFocusEvent} event
     */
    Field.prototype.onFocus = function (event) {
        _super.prototype.onFocus.call(this, event);
        this.setState({ focused: true });
    };
    /**
     * @stable [31.08.2018]
     * @returns {JSX.Element}
     */
    Field.prototype.getInputElement = function () {
        return React.createElement("input", __assign({}, this.getInputElementProps()));
    };
    Field.prototype.getInputElementProps = function () {
        var _this = this;
        var props = this.props;
        var name = props.name;
        var step = props.step;
        var type = props.type || 'text';
        var autoComplete = props.autoComplete || 'off';
        var readOnly = props.readOnly || this.inProgress();
        var placeholder = util_1.orNull(props.placeholder && !this.inProgress(), function () { return _this.t(props.placeholder); });
        var disabled = props.disabled;
        var pattern = this.getFieldPattern();
        var minLength = props.minLength;
        var maxLength = props.maxLength;
        var rows = props.rows;
        var cols = props.cols;
        var onFocus = this.onFocus;
        var onBlur = this.onBlur;
        var onChange = this.onChange;
        var onClick = util_1.orUndef(!this.isFieldInactive(), function () { return _this.onClick; });
        var onKeyDown = util_1.orUndef(!this.isFieldInactive(), function () { return _this.onKeyDown; });
        var onKeyUp = util_1.orUndef(!this.isFieldInactive(), function () { return _this.onKeyUp; });
        var value = this.displayValue;
        return util_1.defValuesFilter({
            name: name, type: type, step: step, readOnly: readOnly, disabled: disabled, pattern: pattern, minLength: minLength, placeholder: placeholder,
            maxLength: maxLength, rows: rows, cols: cols,
            onFocus: onFocus, onBlur: onBlur, onClick: onClick, onChange: onChange, onKeyDown: onKeyDown, onKeyUp: onKeyUp, autoComplete: autoComplete,
            ref: 'input',
            value: value,
            required: this.isFieldRequired(),
            className: 'rac-field-input rac-flex-full',
        });
    };
    /**
     * @stable [18.06.2018]
     * @param {IBasicEvent} event
     */
    Field.prototype.onClick = function (event) {
        util_1.cancelEvent(event);
        _super.prototype.onClick.call(this, event);
    };
    /**
     * @stable [06.10.2018]
     * @returns {string}
     */
    Field.prototype.getFieldClassName = function () {
        var props = this.props;
        return util_1.toClassName('rac-field', 'rac-flex', 'rac-flex-column', util_1.orUndef(!(props.className || '').includes('rac-flex-'), util_1.orUndef(props.full !== false, 'rac-flex-full')), this.isFieldRequired() && 'rac-field-required', this.isFieldInvalid() && 'rac-field-invalid', this.isFieldInactive() && 'rac-field-inactive', this.isValuePresent() ? 'rac-field-value-present' : 'rac-field-value-not-present', this.isNotDefaultValuePresent() && 'rac-field-not-default-value-present', this.isFieldChangeable() ? 'rac-field-changeable' : 'rac-field-not-changeable', this.isFieldFocused() ? 'rac-field-focused' : 'rac-field-not-focused', props.fieldDisplayed !== false ? 'rac-field-displayed' : 'rac-field-no-displayed', props.disabled && 'rac-field-disabled', props.readOnly && 'rac-field-readonly', props.label && 'rac-field-labeled', props.preventFocus && 'rac-field-prevent-focus', props.prefixLabel ? 'rac-field-label-prefixed' : 'rac-field-label-not-prefixed', props.className);
    };
    /**
     * @stable [03.09.2018]
     * @returns {boolean}
     */
    Field.prototype.hasInputFocus = function () {
        return util_1.isElementFocused(this.input);
    };
    Field.prototype.getInputElementWrapperClassName = function () {
        return util_1.toClassName('rac-field-input-wrapper', 'rac-flex', 'rac-flex-full', this.props.inputWrapperClassName);
    };
    /**
     * stable [18.06.2018]
     * @example [
     *            rac-checkbox-field,
     *            rac-text-field
     *          ]
     * @stable
     * @returns Class name
     */
    Field.prototype.getSelfElementClassName = function () {
        return 'rac-self-field';
    };
    /**
     * @stable [31.07.2018]
     * @returns {boolean}
     */
    Field.prototype.isInputValid = function () {
        return !this.hasInput || this.input.validity.valid;
    };
    /**
     * @stable [31.07.2018]
     * @returns {string}
     */
    Field.prototype.getNativeInputValidationMessage = function () {
        return this.input.validationMessage;
    };
    /**
     * @stable [31.07.2018]
     * @param {string} error
     */
    Field.prototype.setNativeInputValidity = function (error) {
        if (this.hasInput) {
            this.input.setCustomValidity(error);
        }
    };
    /**
     * @stable [03.09.2018]
     * @param {string} message
     * @param {string} className
     * @returns {JSX.Element}
     */
    Field.prototype.toMessageElement = function (message, className) {
        return (React.createElement("div", { title: message, className: util_1.toClassName('rac-field-help-text', className) }, message ? this.t(message) : definitions_interface_1.UNI_CODES.noBreakSpace));
    };
    /**
     * @stable [17.06.2018]
     * @param {AnyT} value
     */
    Field.prototype.updateInputBeforeHTML5Validation = function (value) {
        if (this.hasInput) {
            // We must update the field manually before calls HTML5 validation
            this.input.value = value;
        }
    };
    Object.defineProperty(Field.prototype, "jqInput", {
        /**
         * TODO domAccessor
         */
        get: function () {
            return util_1.toJqEl(this.input);
        },
        enumerable: true,
        configurable: true
    });
    return Field;
}(universal_field_component_1.UniversalField));
exports.Field = Field;
//# sourceMappingURL=field.component.js.map