"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var util_1 = require("../../../util");
var field_interface_1 = require("./field.interface");
/**
 * @stable [31.07.2018]
 * @param {IFieldActualChangedValueConfigEntity} config
 * @returns {AnyT}
 */
exports.toActualChangedValue = function (config) {
    var hasOriginalValue = util_1.isDef(config.originalValue);
    if (((hasOriginalValue && R.equals(config.value, config.originalValue))
        || (!hasOriginalValue && R.equals(config.value, config.emptyValue)))
        && config.canReturnClearDirtyChangesValue !== false) {
        return field_interface_1.FIELD_TO_CLEAR_DIRTY_CHANGES_VALUE;
    }
    return config.value;
};
/**
 * @stable [05.10.2018]
 * @param {IUniversalFieldProps} props
 * @returns {boolean}
 */
exports.isFieldRequired = function (props) { return util_1.calc(props.required); };
/**
 * @stable [27.05.2019]
 * @param {IGenericFieldEntity} props
 * @returns {boolean}
 */
exports.isFieldInactive = function (props) {
    return props.disabled || props.readOnly || exports.isFieldInProgress(props);
};
/**
 * @stable [27.05.2019]
 * @param {IGenericFieldEntity} props
 * @returns {boolean}
 */
exports.isFieldInProgress = function (props) { return props.progress; };
/**
 * @stable [06.10.2018]
 * @param {IUniversalFieldProps} props
 * @returns {boolean}
 */
exports.isFieldChangeable = function (props) { return R.isNil(props.changeable) || props.changeable === true; };
//# sourceMappingURL=field.support.js.map