"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var form_support_1 = require("./form.support");
var definitions_interface_1 = require("../../definitions.interface");
var api_1 = require("../../api");
describe('form.support', function () {
    describe('isFormFieldReadOnly', function () {
        it('test1', function () {
            expect(form_support_1.isFormFieldReadOnly({ readOnly: true }, { readOnly: false })).toEqual(false);
        });
        it('test2', function () {
            expect(form_support_1.isFormFieldReadOnly({ readOnly: false }, { readOnly: true })).toEqual(true);
        });
        it('test3', function () {
            expect(form_support_1.isFormFieldReadOnly({ readOnly: false }, {})).toEqual(false);
        });
        it('test4', function () {
            expect(form_support_1.isFormFieldReadOnly({ readOnly: true }, {})).toEqual(true);
        });
        it('test5', function () {
            expect(form_support_1.isFormFieldReadOnly({}, {})).toEqual(false);
        });
    });
    describe('isFormFieldDisabled', function () {
        it('test1', function () {
            expect(form_support_1.isFormFieldDisabled({ disabled: true, form: {} }, { disabled: false })).toEqual(false);
        });
        it('test2', function () {
            expect(form_support_1.isFormFieldDisabled({ disabled: false, form: {} }, { disabled: true })).toEqual(true);
        });
        it('test3', function () {
            expect(form_support_1.isFormFieldDisabled({ disabled: false, form: {} }, {})).toEqual(false);
        });
        it('test4', function () {
            expect(form_support_1.isFormFieldDisabled({ disabled: true, form: {} }, {})).toEqual(true);
        });
        it('test5', function () {
            expect(form_support_1.isFormFieldDisabled({ form: {} }, {})).toEqual(false);
        });
        it('test6', function () {
            expect(form_support_1.isFormFieldDisabled({ disabled: false, form: { progress: true } }, {})).toEqual(true);
        });
        it('test7', function () {
            expect(form_support_1.isFormFieldDisabled({ disabled: false, form: { progress: true } }, { disabled: false })).toEqual(false);
        });
        it('test8', function () {
            expect(form_support_1.isFormFieldDisabled({ disabled: true, form: { progress: true } }, { disabled: false })).toEqual(false);
        });
        it('test9', function () {
            expect(form_support_1.isFormFieldDisabled({ disabled: false, form: { progress: true } }, { disabled: true })).toEqual(true);
        });
    });
    describe('buildApiEntity', function () {
        it('test1', function () {
            var apiEntity = api_1.apiEntityFactory({
                field1: 101,
            }, definitions_interface_1.UNDEF, null);
            expect(apiEntity).toEqual({
                newEntity: true,
                changes: {
                    field1: 101,
                },
                merger: {
                    field1: 101,
                },
            });
        });
        it('test2', function () {
            var apiEntity = api_1.apiEntityFactory({
                field1: 102,
            }, {
                id: 1,
                field1: 101,
                field2: 'fieldValue2',
            }, definitions_interface_1.UNDEF);
            expect(apiEntity).toEqual({
                entityId: 1,
                newEntity: false,
                changes: {
                    field1: 102,
                },
                merger: {
                    id: 1,
                    field1: 102,
                    field2: 'fieldValue2',
                },
                entity: {
                    id: 1,
                    field1: 101,
                    field2: 'fieldValue2',
                },
            });
        });
        it('test3', function () {
            var apiEntity = api_1.apiEntityFactory({}, {
                id: 1,
                field1: 101,
                field2: 'fieldValue2',
            }, definitions_interface_1.UNDEF);
            expect(apiEntity).toEqual({
                entityId: 1,
                newEntity: false,
                changes: {},
                merger: {
                    id: 1,
                    field1: 101,
                    field2: 'fieldValue2',
                },
                entity: {
                    id: 1,
                    field1: 101,
                    field2: 'fieldValue2',
                },
            });
        });
    });
});
//# sourceMappingURL=form.support.spec.js.map