"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var definitions_interface_1 = require("../../definitions.interface");
var util_1 = require("../../util");
var field_1 = require("../field");
var header_1 = require("./header");
var column_1 = require("./column");
var list_1 = require("../list");
var row_1 = require("./row");
var field_2 = require("../field");
var layout_1 = require("../layout");
var grid_support_1 = require("./grid.support");
var Grid = /** @class */ (function (_super) {
    __extends(Grid, _super);
    /**
     * @stable [07.06.2018]
     * @param {IGridProps} props
     */
    function Grid(props) {
        var _this = _super.call(this, props) || this;
        _this.onSortingDirectionChange = _this.onSortingDirectionChange.bind(_this);
        _this.onSettingsClick = _this.onSettingsClick.bind(_this);
        _this.onPlusClick = _this.onPlusClick.bind(_this);
        _this.state = { filterChanges: {}, expandedGroups: {} };
        return _this;
    }
    /**
     * @stable [09.09.2018]
     * @returns {JSX.Element}
     */
    Grid.prototype.getView = function () {
        var _this = this;
        var props = this.props;
        var dataSource = this.dataSource;
        var gridEl = (React.createElement(layout_1.FlexLayout, { row: true, className: util_1.toClassName('rac-grid-wrapper', props.wrapperClassName) },
            React.createElement("table", { cellPadding: 0, cellSpacing: 0, className: util_1.toClassName('rac-grid', props.tightGrid && 'rac-tight-grid', props.className) },
                React.createElement("thead", { className: util_1.toClassName('rac-grid-head', props.stickyHead && definitions_interface_1.UNIVERSAL_STICKY_ELEMENT_SELECTOR) },
                    this.headerElement,
                    this.filterElement),
                React.createElement("tbody", { className: 'rac-grid-body' },
                    util_1.ifNotFalseThanValue(props.topTotal, function () { return _this.totalRowElement; }),
                    util_1.isDef(props.groupBy)
                        ? this.getGroupedRows(dataSource)
                        : dataSource.map(function (entity, index) { return _this.getRow(entity, index, true); }),
                    util_1.orNull(props.topTotal === false, function () { return _this.totalRowElement; }))),
            this.addActionElement));
        if (!props.useService) {
            return gridEl;
        }
        return (React.createElement(layout_1.FlexLayout, { row: true },
            gridEl,
            React.createElement("div", { className: 'rac-grid-service-wrapper' },
                React.createElement("div", { className: 'rac-grid-service' }, util_1.orNull(props.useService, function () { return _this.uiFactory.makeIcon({ type: 'more_vert', onClick: _this.onSettingsClick }); })))));
    };
    /**
     * @stable [07.06.2018]
     * @returns {IEntity[]}
     */
    Grid.prototype.filterAndSortOriginalDataSourceUsingLocalFiltersAndSorters = function () {
        return grid_support_1.filterAndSortGridOriginalDataSource(this.originalDataSource, this.columnsConfiguration, this.props, this.state);
    };
    Grid.prototype.onSettingsClick = function () {
        // TODO
    };
    /**
     * @stable [12.08.2018]
     */
    Grid.prototype.onPlusClick = function () {
        var props = this.props;
        if (props.onPlusClick) {
            props.onPlusClick();
        }
    };
    /**
     * @stable - 05.04.2018
     * @param {ISortDirectionEntity} payload
     */
    Grid.prototype.onSortingDirectionChange = function (payload) {
        var props = this.props;
        if (props.onChangeSorting) {
            props.onChangeSorting(payload);
        }
    };
    /**
     * @stable [06.06.2018]
     * @param {IFieldChangeEntity} payload
     */
    Grid.prototype.onChangeRowField = function (payload) {
        var props = this.props;
        if (props.onChange) {
            props.onChange(payload);
        }
    };
    /**
     * @stable [07.06.2018]
     * @param {IFieldChangeEntity} payload
     */
    Grid.prototype.onChangeGroupingRowField = function (payload) {
        var props = this.props;
        if (props.onChangeGrouping) {
            props.onChangeGrouping(payload);
        }
    };
    /**
     * @stable [07.06.2018]
     * @param {IFieldChangeEntity} payload
     */
    Grid.prototype.onChangeHeaderField = function (payload) {
        var props = this.props;
        if (props.onChangeHeader) {
            props.onChangeHeader(payload);
        }
    };
    /**
     * @stable [07.06.2018]
     * @param {IFieldChangeEntity} payload
     */
    Grid.prototype.onChangeFilterField = function (payload) {
        var _a;
        var props = this.props;
        if (props.useLocalFiltering) {
            this.setState({
                filterChanges: __assign({}, this.state.filterChanges, (_a = {}, _a[payload.name] = payload.value, _a)),
            });
        }
        else if (props.onChangeFilter) {
            props.onChangeFilter(payload);
        }
    };
    /**
     * @stable - 06.04.2018
     * @param {IGridColumnConfiguration} column
     * @param {number} columnNum
     * @returns {React.ReactNode}
     */
    Grid.prototype.getHeaderColumnContent = function (column, columnNum) {
        var _this = this;
        if (column.useGrouping) {
            var name_1 = this.toHeaderFieldName(columnNum);
            return (React.createElement(field_1.Checkbox, __assign({}, this.getDefaultFieldProps(), { name: name_1, value: this.toCheckboxFieldValue(name_1), onChange: function (value) { return _this.onChangeHeaderField({ value: value, name: name_1 }); } })));
        }
        else if (util_1.isFn(column.headerRenderer)) {
            return column.headerRenderer(column);
        }
        return this.t(column.title);
    };
    Object.defineProperty(Grid.prototype, "headerElement", {
        /**
         * @stable - 06.04.2018
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            return (React.createElement(row_1.GridRow, { className: 'rac-grid-header' }, this.columnsConfiguration.map(function (column, columnNum) { return (React.createElement(header_1.GridHeaderColumn, __assign({ key: _this.toHeaderColumnKey(columnNum), name: column.name, index: columnNum, direction: grid_support_1.getGridColumnSortDirection(column, _this.props), onSortingDirectionChange: _this.onSortingDirectionChange }, column), _this.getHeaderColumnContent(column, columnNum))); })));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [07.06.2018]
     * @param {IEntity} entity
     * @param {IGridColumnConfiguration} column
     * @param {number} columnNum
     * @param {number} rowNum
     * @param {IEntity[]} groupedRows
     * @returns {React.ReactNode}
     */
    Grid.prototype.getColumn = function (entity, column, columnNum, rowNum, groupedRows) {
        var _this = this;
        var name = this.toFieldName(entity, column, columnNum);
        if (column.useGrouping) {
            return (
            /**
             * Default group field
             */
            React.createElement(field_1.Checkbox, __assign({}, this.getDefaultFieldProps(), { name: name, value: this.toCheckboxFieldValue(name), onChange: function (value) { return _this.onChangeGroupingRowField({ value: value, name: name, rawData: entity }); } })));
        }
        else if (column.tpl) {
            /**
             * Build using a text template
             */
            return column.tpl(entity, column, rowNum);
        }
        else if (column.renderer) {
            /**
             * Build using a renderer
             */
            var renderEl = column.renderer(entity, column, groupedRows);
            if (R.isNil(renderEl)) {
                return renderEl;
            }
            if (this.isElementField(renderEl)) {
                return React.cloneElement(renderEl, __assign({}, this.getDefaultFieldProps(renderEl.props), { name: column.name, value: util_1.isDef(renderEl.props.value) ? renderEl.props.value : Reflect.get(entity, column.name), onChange: function (value) { return _this.onChangeRowField({ value: value, name: name, rawData: entity }); } }));
            }
            return renderEl;
        }
        else if (column.name) {
            /**
             * Build by a column name
             */
            return Reflect.get(entity, column.name);
        }
        return null;
    };
    /**
     * @stable [07.06.2018]
     * @param {IGridColumnConfiguration} column
     * @param {number} columnNum
     * @returns {React.ReactNode}
     */
    Grid.prototype.getFilterColumn = function (column, columnNum) {
        var _this = this;
        if (column.filterRenderer) {
            /**
             * Build using a renderer
             */
            var renderEl = column.filterRenderer(column);
            if (R.isNil(renderEl)) {
                return renderEl;
            }
            if (this.isElementField(renderEl)) {
                var name_2 = this.toFilterFieldName(column, columnNum);
                return React.cloneElement(renderEl, __assign({}, this.getDefaultFieldProps(), { value: this.toFilterFieldValue(name_2), placeholder: 'Filter', clearActionRendered: true, onChange: function (value) { return _this.onChangeFilterField({ value: value, name: name_2 }); } }));
            }
            return renderEl;
        }
        return null;
    };
    /**
     * @stable - 05.04.2018
     * @param {IEntity} entity
     * @param {number} rowNum
     * @param {boolean} applyOddClassName
     * @param {IEntity[]} groupedRows
     * @returns {JSX.Element}
     */
    Grid.prototype.getRow = function (entity, rowNum, applyOddClassName, groupedRows) {
        var _this = this;
        var props = this.props;
        var rowKey = this.toRowKey(entity);
        var changes = props.changes;
        var entityChanges = changes[entity.id];
        return (React.createElement(row_1.GridRow, { ref: rowKey, key: rowKey, className: util_1.toClassName('rac-grid-data-row', "rac-grid-data-row-" + entity.id, util_1.orUndef(props.applyOdd !== false && applyOddClassName && util_1.isOddNumber(rowNum), 'rac-grid-data-row-odd'), util_1.orUndef(props.hovered !== false, 'rac-grid-data-row-hovered'), util_1.orUndef(this.isRowSelectable, 'rac-grid-data-row-selectable')), selected: this.isEntitySelected(entity), onClick: function () { return _this.onSelect(entity); } }, this.columnsConfiguration.map(function (column, columnNum) { return (React.createElement(column_1.GridColumn, __assign({ key: rowKey + "-" + columnNum, index: columnNum, className: util_1.toClassName(!R.isNil(entityChanges) && util_1.isDef(entityChanges[column.name]) && 'rac-grid-column-edited'), entity: entity }, column), _this.getColumn(entity, column, columnNum, rowNum, groupedRows))); })));
    };
    Object.defineProperty(Grid.prototype, "filterElement", {
        /**
         * @stable - 05.04.2018
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var columns = this.columnsConfiguration;
            var isAtLeastOneFilterExist = columns
                .filter(function (column) { return !R.isNil(column.filterRenderer); }).length > 0;
            return (util_1.orNull(isAtLeastOneFilterExist, function () { return (React.createElement(row_1.GridRow, { className: 'rac-grid-filter-row' }, columns.map(function (column, columnNum) { return (React.createElement(header_1.GridHeaderColumn, __assign({ key: _this.toFilterColumnKey(columnNum), index: columnNum }, column), _this.getFilterColumn(column, columnNum))); }))); }));
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [07.06.2018]
     * @param {string} name
     * @returns {AnyT}
     */
    Grid.prototype.toFilterFieldValue = function (name) {
        var props = this.props;
        var state = this.state;
        return util_1.orUndef(props.useLocalFiltering, function () { return state.filterChanges[name]; });
    };
    /**
     * @stable [07.06.2018]
     * @returns {IFieldProps}
     */
    Grid.prototype.getDefaultFieldProps = function (fieldProps) {
        return {
            errorMessageRendered: false,
            readOnly: (fieldProps && fieldProps.readOnly) || this.props.deactivated,
        };
    };
    /**
     * @stable [07.06.2018]
     * @param {IEntity} entity
     * @param {IGridColumnConfiguration} column
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toFieldName = function (entity, column, columnNum) {
        return column.name || "$$dynamic-field-" + entity.id + "-" + columnNum; // Infinity scroll supporting
    };
    /**
     * @stable [07.06.2018]
     * @param {IGridColumnConfiguration} column
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toFilterFieldName = function (column, columnNum) {
        return column.name || "$$dynamic-filter-field-" + columnNum;
    };
    /**
     * @stable - 06.04.2018
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toHeaderFieldName = function (columnNum) {
        return "$$dynamic-header-field-" + columnNum;
    };
    /**
     * @stable - 05.04.2018
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toFilterColumnKey = function (columnNum) {
        return "grid-filter-column-" + columnNum;
    };
    /**
     * @stable - 05.04.2018
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toHeaderColumnKey = function (columnNum) {
        return "grid-header-column-" + columnNum;
    };
    /**
     * @stable - 06.04.2018
     * @param {string} fieldName
     * @returns {AnyT}
     */
    Grid.prototype.toFieldValue = function (fieldName) {
        return this.props.changes[fieldName];
    };
    /**
     * @stable - 06.04.2018
     * @param {string} fieldName
     * @returns {AnyT}
     */
    Grid.prototype.toCheckboxFieldValue = function (fieldName) {
        var fieldValue = this.toFieldValue(fieldName);
        return util_1.isDef(fieldValue) ? fieldValue : false;
    };
    /**
     * @stable [07.06.2018]
     * @param {JSX.Element} renderEl
     * @returns {boolean}
     */
    Grid.prototype.isElementField = function (renderEl) {
        return field_2.Field.isPrototypeOf(renderEl.type);
    };
    Object.defineProperty(Grid.prototype, "columnsConfiguration", {
        /**
         * @stable [10.10.2018]
         * @returns {IGridColumnConfiguration[]}
         */
        get: function () {
            return R.filter(function (column) { return column.rendered !== false; }, this.props.columnsConfiguration);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [04.07.2018]
     * @param {EntityIdT} groupedRowValue
     * @returns {string}
     */
    Grid.prototype.toGroupedRowKey = function (groupedRowValue) {
        return "data-grouped-row-" + groupedRowValue;
    };
    /**
     * @stable [27.12.2018]
     * @returns {string}
     */
    Grid.prototype.toTotalRowKey = function () {
        return "data-total-row";
    };
    /**
     * @stable [05.10.2018]
     * @param {EntityIdT} groupedRowValue
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toGroupedColumnKey = function (groupedRowValue, columnNum) {
        return "data-grouped-column-" + groupedRowValue + "-" + columnNum;
    };
    /**
     * @stable [27.12.2018]
     * @param {number} columnNum
     * @returns {string}
     */
    Grid.prototype.toTotalColumnKey = function (columnNum) {
        return "data-total-column-" + columnNum;
    };
    /**
     * @stable [06.09.2018]
     * @param {IEntity[]} dataSource
     * @returns {JSX.Element[]}
     */
    Grid.prototype.getGroupedRows = function (dataSource) {
        var _this = this;
        if (R.isEmpty(dataSource)) {
            return [];
        }
        var groupedDataSorter = this.props.groupedDataSorter;
        var dataSource0 = util_1.isFn(groupedDataSorter)
            ? R.sort(function (entity1, entity2) {
                return groupedDataSorter(_this.extractGroupedValue(entity1), _this.extractGroupedValue(entity2), entity1, entity2);
            }, dataSource)
            : dataSource;
        var rows = [];
        var groupedDataSource = {};
        dataSource0.forEach(function (entity) {
            var groupColumnValue = _this.extractGroupedValue(entity);
            var groupedDataSourceEntities = Reflect.get(groupedDataSource, groupColumnValue);
            if (!groupedDataSource.hasOwnProperty(groupColumnValue)) {
                Reflect.set(groupedDataSource, groupColumnValue, groupedDataSourceEntities = []);
            }
            groupedDataSourceEntities.push(entity);
        });
        Object.keys(groupedDataSource).forEach(function (groupedRowValue) {
            var groupedRows = groupedDataSource[groupedRowValue];
            rows.push(_this.getGroupingRow(groupedRowValue, groupedRows));
            if (_this.isGroupedRowExpanded(groupedRowValue)) {
                var applyOddClassName_1 = groupedRows.length > 1;
                groupedRows.forEach(function (entity, index) { return rows.push(_this.getRow(entity, index, applyOddClassName_1, groupedRows)); });
            }
        });
        return rows;
    };
    /**
     * @stable [04.07.2018]
     * @param {EntityIdT} groupedRowValue
     * @param {IEntity[]} groupedRows
     * @returns {JSX.Element}
     */
    Grid.prototype.getGroupingRow = function (groupedRowValue, groupedRows) {
        var _this = this;
        var props = this.props;
        var groupBy = props.groupBy;
        var groupValue = groupBy.groupValue;
        var isGroupValueArray = Array.isArray(groupValue);
        var isExpanded = this.isGroupedRowExpanded(groupedRowValue);
        var expandActionRendered = props.expandActionRendered !== false;
        var columns = this.columnsConfiguration;
        return (React.createElement(row_1.GridRow, { key: this.toGroupedRowKey(groupedRowValue), className: util_1.toClassName('rac-grid-data-row', 'rac-grid-data-row-grouped', props.applyGroup !== false && isExpanded && 'rac-grid-data-row-group-expanded') }, columns.map(function (column, columnNum) {
            var key = _this.toGroupedColumnKey(groupedRowValue, columnNum);
            var contentKey = _this.toGroupedColumnKey(groupedRowValue + "-content", columnNum);
            var node = (columnNum === 0
                ? (React.createElement(layout_1.FlexLayout, { row: true, full: false, key: contentKey },
                    expandActionRendered && (_this.uiFactory.makeIcon({
                        key: contentKey + "-expanded-action-" + (isExpanded ? 'close' : 'open'),
                        className: 'rac-grid-data-row-group-expanded-icon',
                        type: isExpanded ? 'close-list' : 'open-list',
                        onClick: function (event) { return _this.onExpandGroup(event, groupedRowValue, !isExpanded); },
                    })),
                    " ",
                    util_1.isFn(groupValue)
                        ? groupValue(groupedRowValue, groupedRows)
                        : (isGroupValueArray
                            ? (util_1.isFn(groupValue[0]) ? groupValue[0](groupedRowValue, groupedRows) : null)
                            : groupedRowValue)))
                : (util_1.orNull(isGroupValueArray && util_1.isFn(groupValue[columnNum]), function () { return groupValue[columnNum](groupedRowValue, groupedRows); })));
            return (React.createElement(column_1.GridColumn, __assign({ key: key }, column), node));
        })));
    };
    Object.defineProperty(Grid.prototype, "totalRowElement", {
        /**
         * @stable [27.12.2018]
         * @returns {JSX.Element}
         */
        get: function () {
            var _this = this;
            var props = this.props;
            var totalEntity = props.totalEntity;
            var columns = this.columnsConfiguration;
            return util_1.ifNotNilThanValue(totalEntity, function () { return (React.createElement(row_1.GridRow, { key: _this.toTotalRowKey(), className: 'rac-grid-data-row rac-grid-data-row-total' }, columns.map(function (column, columnNum) { return (React.createElement(column_1.GridColumn, __assign({ key: _this.toTotalColumnKey(columnNum) }, column), totalEntity[column.name])); }))); });
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [04.07.2018]
     * @param {IBasicEvent} event
     * @param {EntityIdT} groupedRowValue
     * @param {boolean} expanded
     */
    Grid.prototype.onExpandGroup = function (event, groupedRowValue, expanded) {
        var _a;
        util_1.cancelEvent(event);
        this.setState({ expandedGroups: __assign({}, this.state.expandedGroups, (_a = {}, _a[groupedRowValue] = expanded, _a)) });
    };
    /**
     * @stable [03.09.2018]
     * @param {EntityIdT} groupedRowValue
     * @returns {boolean}
     */
    Grid.prototype.isGroupedRowExpanded = function (groupedRowValue) {
        var state = this.state;
        var props = this.props;
        return util_1.coalesce(!R.isNil(state.expandedGroups) && Reflect.get(state.expandedGroups, groupedRowValue), !R.isNil(props.expandedGroups) && Reflect.get(props.expandedGroups, groupedRowValue), false);
    };
    /**
     * @stable [07.03.2019]
     * @param {IEntity} entity
     * @returns {AnyT}
     */
    Grid.prototype.extractGroupedValue = function (entity) {
        var groupBy = this.props.groupBy;
        return Reflect.get(entity, groupBy.columnName);
    };
    return Grid;
}(list_1.BaseList));
exports.Grid = Grid;
//# sourceMappingURL=grid.component.js.map