"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var util_1 = require("../../../util");
var configurations_definitions_interface_1 = require("../../../configurations-definitions.interface");
var UniversalLayoutViewBuilder = /** @class */ (function () {
    function UniversalLayoutViewBuilder() {
    }
    /**
     * @stable [22.10.2018]
     * @param {UniversalLayoutBuilderChildrenT<TNode>} item
     * @returns {boolean}
     */
    UniversalLayoutViewBuilder.prototype.isClonedItem = function (item) {
        var itemEl = item;
        var type = itemEl.type;
        return util_1.isFn(type)
            || (util_1.isString(type) && !R.isEmpty(type)); // type = {'div', 'span', ...}
    };
    /**
     * @stable [22.10.2018]
     * @param {TNode} item
     * @param {IUniversalLayoutBuilderConfiguration<TNode>} layoutConfig
     * @param {IKeyValue} props
     * @returns {IKeyValue}
     */
    UniversalLayoutViewBuilder.prototype.getClonedItemProps = function (item, layoutConfig, props) {
        return props;
    };
    /**
     * @stable [22.10.2018]
     * @param {TNode} item
     * @param {IKeyValue} props
     * @returns {TNode}
     */
    UniversalLayoutViewBuilder.prototype.cloneItem = function (item, props) {
        return item;
    };
    /**
     * @stable [22.10.2018]
     * @param {IUniversalLayoutBuilderConfiguration<TNode>} config
     * @returns {string}
     */
    UniversalLayoutViewBuilder.prototype.toFactorClassName = function (config) {
        if (config.full === false) {
            return '';
        }
        switch (config.factor) {
            case configurations_definitions_interface_1.LayoutBuilderFactorEnum.FACTOR_0_5:
                return 'rac-flex-half';
            case configurations_definitions_interface_1.LayoutBuilderFactorEnum.FACTOR_0_75:
                return 'rac-flex-three-quarters';
            case configurations_definitions_interface_1.LayoutBuilderFactorEnum.FACTOR_2:
                return 'rac-flex-full-x2';
            case configurations_definitions_interface_1.LayoutBuilderFactorEnum.FACTOR_4:
                return 'rac-flex-full-x4';
            case configurations_definitions_interface_1.LayoutBuilderFactorEnum.FACTOR_8:
                return 'rac-flex-full-x8';
            default:
                return 'rac-flex-full';
        }
    };
    return UniversalLayoutViewBuilder;
}());
exports.UniversalLayoutViewBuilder = UniversalLayoutViewBuilder;
//# sourceMappingURL=universal-layout-view.builder.js.map