"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var R = require("ramda");
var util_1 = require("../../../util");
var base_1 = require("../../base");
var link_1 = require("../../link");
var configurations_definitions_interface_1 = require("../../../configurations-definitions.interface");
var list_1 = require("../../list");
var layout_1 = require("../../layout");
var entities_definitions_interface_1 = require("../../../entities-definitions.interface");
var NavigationList = /** @class */ (function (_super) {
    __extends(NavigationList, _super);
    /**
     * @stable [11.08.2018]
     * @param {INavigationListProps} props
     */
    function NavigationList(props) {
        var _this = _super.call(this, props) || this;
        _this.toElement = _this.toElement.bind(_this);
        return _this;
    }
    /**
     * @stable [23.09.2018]
     * @returns {JSX.Element}
     */
    NavigationList.prototype.render = function () {
        return (React.createElement("nav", { ref: 'self', className: 'rac-navigation-list rac-no-user-select', onScroll: this.onNativeScroll },
            React.createElement(list_1.ListDivider, null),
            this.props.items.map(this.toElement)));
    };
    /**
     * @stable [17.12.2018]
     */
    NavigationList.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        this.domAccessor.scrollTo(this.props, this.getSelf());
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationListItemConfiguration} item
     * @returns {JSX.Element}
     */
    NavigationList.prototype.toElement = function (item) {
        var _this = this;
        var isExpanded = this.isItemExpanded(item);
        var fullLayoutModeEnabled = this.fullLayoutModeEnabled;
        var label = this.t(item.label);
        switch (item.type) {
            case configurations_definitions_interface_1.NavigationListItemTypeEnum.SUB_HEADER:
                var isGroupItemActive = !isExpanded && this.hasActiveChild(item);
                return (React.createElement(layout_1.FlexLayout, { key: this.toUniqueKey(item.label, 'label'), row: true, alignItemsCenter: true, className: util_1.toClassName('rac-navigation-list-group', isGroupItemActive
                        ? 'rac-navigation-list-item-active'
                        : (isExpanded ? 'rac-navigation-list-item-expanded' : '')), title: label, onClick: function () { return _this.onGroupLinkClick(item); } },
                    this.uiFactory.makeIcon({
                        key: this.toUniqueKey(item.label, 'group-icon'),
                        type: item.icon || 'list',
                        className: 'rac-navigation-list-icon',
                    }),
                    util_1.orNull(fullLayoutModeEnabled, function () { return React.createElement("span", { className: 'rac-navigation-list-group-label rac-flex-full' }, label); }),
                    util_1.orNull(fullLayoutModeEnabled, function () { return (_this.uiFactory.makeIcon({
                        key: _this.toUniqueKey(item.label, 'group-expand-icon'),
                        type: isExpanded ? 'dropdown-opened' : 'dropdown',
                        className: 'rac-navigation-list-group-expand-icon rac-navigation-list-icon',
                    })); })));
            case configurations_definitions_interface_1.NavigationListItemTypeEnum.DIVIDER:
                return React.createElement(list_1.ListDivider, { key: R.isNil(item.parent) ? util_1.uuid() : this.toUniqueKey(item.parent.label, 'divider') });
            default:
                var itemAsGroup_1 = R.isNil(item.parent);
                return util_1.orNull(isExpanded || itemAsGroup_1, function () { return (React.createElement(link_1.Link, { to: item.link, key: _this.toUniqueKey(item.link, 'link'), className: util_1.toClassName('rac-navigation-list-item', item.active
                        ? 'rac-navigation-list-item-active'
                        : (isExpanded ? 'rac-navigation-list-item-expanded' : ''), itemAsGroup_1 && 'rac-navigation-list-item-as-group', 'rac-flex', 'rac-flex-row', 'rac-flex-full', 'rac-flex-align-items-center'), title: label },
                    _this.uiFactory.makeIcon({
                        type: item.icon,
                        key: _this.toUniqueKey(item.link, 'icon'),
                        className: 'rac-navigation-list-icon',
                    }),
                    util_1.orNull(fullLayoutModeEnabled, function () { return React.createElement("span", { className: 'rac-navigation-list-item-label' }, label); }))); });
        }
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationListItemConfiguration} config
     */
    NavigationList.prototype.onGroupLinkClick = function (config) {
        var props = this.props;
        if (props.onGroupClick) {
            props.onGroupClick(config);
        }
    };
    /**
     * @stable [23.09.2018]
     * @param {string} link
     * @param {string} prefix
     * @returns {string}
     */
    NavigationList.prototype.toUniqueKey = function (link, prefix) {
        return "navigation-list-key-" + link + "-" + prefix;
    };
    /**
     * @stable [23.09.2018]
     * @param {INavigationListItemConfiguration} item
     * @returns {boolean}
     */
    NavigationList.prototype.isItemExpanded = function (item) {
        var expandedGroups = this.props.expandedGroups;
        return expandedGroups[item.value] === true
            || (!R.isNil(item.parent) && expandedGroups[item.parent.value] === true);
    };
    Object.defineProperty(NavigationList.prototype, "fullLayoutModeEnabled", {
        /**
         * @stable [23.09.2018]
         * @returns {boolean}
         */
        get: function () {
            return this.props.mode === entities_definitions_interface_1.LayoutModeEnum.FULL;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [23.09.2018]
     * @param {INavigationListItemConfiguration} item
     * @returns {boolean}
     */
    NavigationList.prototype.hasActiveChild = function (item) {
        var activeItem = R.find(function (itm) { return !!itm.active; }, this.props.items);
        return !R.isNil(activeItem) && !R.isNil(R.find(function (child) { return child.link === activeItem.link; }, item.children || []));
    };
    return NavigationList;
}(base_1.BaseComponent));
exports.NavigationList = NavigationList;
//# sourceMappingURL=navigation-list.component.js.map