"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var util_1 = require("../../util");
var action_builder_1 = require("../../component/action.builder");
/**
 * @stable [31.08.2018]
 * @param {IUntouchedListMiddlewareConfig<TApplicationState>} config
 * @returns {(action: IEffectsAction, state: TApplicationState) => IEffectsAction}
 */
exports.makeUntouchedListMiddleware = function (config) {
    return function (action, state) {
        return util_1.orNull(!(util_1.isFn(config.listAccessor)
            ? config.listAccessor(state).touched
            : config.resolver(state).list.touched), // Deprecated
        function () { return action_builder_1.ListActionBuilder.buildLoadAction(config.listSection); });
    };
};
/**
 * @stable [31.08.2018]
 * @param {IUntouchedListMiddlewareConfig<TApplicationState>} config
 * @returns {(action: IEffectsAction, state: TApplicationState) => IEffectsAction}
 */
exports.makeUntouchedLazyLoadedListMiddleware = function (config) {
    return function (action, state) {
        if (!util_1.isFn(config.lazyLoadedSection)) {
            return action_builder_1.ListActionBuilder.buildLoadAction(config.listSection);
        }
        var lazyLoadedSection = config.lazyLoadedSection(state, action);
        return util_1.orNull(!R.isNil(lazyLoadedSection) && !config.lazyLoadedResolver(state, action).list.touched, function () { return action_builder_1.ListActionBuilder.buildLoadAction(lazyLoadedSection); });
    };
};
//# sourceMappingURL=untouched-list.middleware.js.map