"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var graphlib = require("@dagrejs/graphlib");
var R = require("ramda");
// TODO toAllDependentSections
exports.getDestroyableSections = function (currentSection, state) {
    var sectionsToDestroy = new Set();
    var gr = new graphlib.Graph();
    state.stack.forEach(function (entry) {
        gr.setNode(entry.section);
        entry.linkedToSections.forEach(function (linkedSection) {
            gr.setNode(linkedSection);
            gr.setEdge(entry.section, linkedSection);
        });
    });
    var graphComponents = graphlib.alg.components(gr);
    graphComponents.forEach(function (graphComponent) {
        if (!R.contains(currentSection, graphComponent)) {
            graphComponent.forEach(function (entry) { return sectionsToDestroy.add(entry); });
        }
    });
    var needToDestroySections = state.needToDestroySections;
    if (needToDestroySections) {
        needToDestroySections.forEach(function (sectionNeedToDestroy) { return sectionsToDestroy.add(sectionNeedToDestroy); });
    }
    return Array.from(sectionsToDestroy);
};
exports.lockNextSection = function (nextSection, state) {
    var stack = state.stack;
    var stackLength = stack.length;
    // If there is a lock - we must put the next section to linked stack
    return stack.map(function (entry, index) { return (index === stackLength - 1
        ? __assign({}, entry, { linkedToSections: Array.from(new Set(entry.linkedToSections.concat(nextSection)
                .filter(function (section) { return section !== entry.section; })) // Prevent the recursive links
            ) }) : entry); });
};
exports.destroySections = function (sectionsToDestroy, state) {
    var stack = state.stack;
    return R.filter(function (entry) {
        return !R.contains(entry.section, sectionsToDestroy);
    }, stack);
};
exports.pushNextSection = function (nextSection, state) {
    var stack = state.stack;
    var currentSectionIndex = R.findIndex(function (entry) { return entry.section === nextSection; }, stack);
    return currentSectionIndex > -1
        ? [].concat(stack)
        : R.insert(stack.length, { section: nextSection, linkedToSections: [] }, stack);
};
//# sourceMappingURL=stack.helper.js.map