"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var validator_1 = require("./validator");
/**
 * @stable [30.01.2019]
 * @param {Record<string, ValidatorRuleEnum[]>} payloads
 * @param {IEditableEntity<TEntity extends IEntity>} editableEntity
 * @param {boolean} canSaveEmptyChanges
 * @returns {boolean}
 */
exports.canSubmitEditableEntity = function (payloads, editableEntity, canSaveEmptyChanges) {
    if (canSaveEmptyChanges === void 0) { canSaveEmptyChanges = false; }
    return !editableEntity.progress
        && validator_1.validate(payloads, editableEntity.changes).valid
        && (canSaveEmptyChanges || !R.isEmpty(editableEntity.changes));
};
/**
 * @stable [30.01.2019]
 * @param {IEntityFormEntity<TEntity extends IEntity>} entity
 * @param {Record<string, ValidatorRuleEnum[]>} editRules
 * @param {Record<string, ValidatorRuleEnum[]>} createRules
 * @returns {boolean}
 */
exports.canSubmitEntityFormEntity = function (entity, editRules, createRules) {
    return exports.canSubmitEditableEntity(exports.doesEntityExist(entity) ? editRules : createRules || editRules, entity.form);
};
/**
 * @stable [30.01.2019]
 * @param {IEditableEntity<TEntity extends IEntity>} editableEntity
 * @returns {boolean}
 */
exports.isEditableEntityBusy = function (editableEntity) {
    return editableEntity.progress === true;
};
/**
 * @stable [30.01.2019]
 * @param {IEntityFormEntity<TEntity extends IEntity>} entity
 * @returns {boolean}
 */
exports.isEntityFormEntityBusy = function (entity) {
    return exports.isEditableEntityBusy(entity.form);
};
/**
 * @stable [30.01.2019]
 * @param {IExtendedEntity<TEntity extends IEntity>} entityWrapper
 * @returns {boolean}
 */
exports.isNewEntity = function (entityWrapper) {
    return entityWrapper.newEntity === true;
};
/**
 * @stable [30.01.2019]
 * @param {IExtendedEntity<TEntity extends IEntity>} entityWrapper
 * @returns {boolean}
 */
exports.doesEntityExist = function (entityWrapper) {
    return !exports.isNewEntity(entityWrapper);
};
//# sourceMappingURL=entity.js.map