import { ITransportRequestPayloadFactory, ITransportRequestPayloadEntity } from './transport-request-payload-factory.interface';
import { ITransportCancelTokenEntity, ITransportRequestEntity } from '../../transport.interface';
import { ISettings } from '../../../settings';
import { IKeyValue } from '../../../definitions.interface';
export declare abstract class BaseTransportRequestPayloadFactory implements ITransportRequestPayloadFactory {
    protected settings: ISettings;
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @param {ITransportCancelTokenEntity} cancelToken
     * @returns {ITransportRequestPayloadEntity}
     */
    makeRequestPayload(requestEntity: ITransportRequestEntity, cancelToken?: ITransportCancelTokenEntity): ITransportRequestPayloadEntity;
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} req
     * @returns {IKeyValue}
     */
    abstract makeRequestPayloadData(req: ITransportRequestEntity): IKeyValue;
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {string}
     */
    protected getUrl(requestEntity: ITransportRequestEntity): string;
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {string}
     */
    protected getBaseUrl(requestEntity: ITransportRequestEntity): string;
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {boolean}
     */
    protected getWithCredentials(requestEntity: ITransportRequestEntity): boolean;
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {string}
     */
    protected getMethod(requestEntity: ITransportRequestEntity): string;
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {IKeyValue}
     */
    protected getData(requestEntity: ITransportRequestEntity): IKeyValue;
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {IKeyValue}
     */
    protected getHeaders(requestEntity: ITransportRequestEntity): IKeyValue;
    /**
     * @stable [02.02.2019]
     * @param {ITransportRequestEntity} requestEntity
     * @returns {boolean}
     */
    protected isBinaryData(requestEntity: ITransportRequestEntity): boolean;
}
